@@ -12,13 +12,22 @@ logger = get_qwak_logger()
 
 @click.command("status", cls=QwakCommand)
 @click.argument("build_id")
-def get_build_status(build_id, **kwargs):
-    if kwargs["format"] == "text":
+@click.option(
+    "--format",
+    default="text",
+    show_default=True,
+    type=click.Choice(["text", "json"], case_sensitive=True),
+    metavar="FORMAT",
+    required=False,
+    help="The formatting style for commands output (choose from text, json)",
+)
+def get_build_status(build_id, format, **kwargs):
+    if format == "text":
         logger.info(f"Getting build status for build id [{build_id}]")
     build_status = execute_get_build_status(build_id)
-    if kwargs["format"] == "text":
+    if format == "text":
         logger.info(f"Build status: {BuildStatus.Name(build_status)}")
-    elif kwargs["format"] == "json":
+    elif format == "json":
         print(
             json.dumps(
                 {
