@@ -22,5 +22,14 @@ from qwak_sdk.inner.tools.cli_tools import QwakCommand
     help="Returns the list of builds of model",
     is_flag=True,
 )
-def model_describe(model_id, interface, list_builds, **kwargs):
-    execute_model_describe(model_id, interface, list_builds, **kwargs)
+@click.option(
+    "--format",
+    default="text",
+    show_default=True,
+    type=click.Choice(["text", "json"], case_sensitive=True),
+    metavar="FORMAT",
+    required=False,
+    help="The formatting style for commands output (choose from text, json)",
+)
+def model_describe(model_id, interface, list_builds, format, **kwargs):
+    execute_model_describe(model_id, interface, list_builds, format)
