@@ -22,10 +22,19 @@ def parse_model(model):
 
 @click.command("list", cls=QwakCommand)
 @click.option("--project-id", metavar="NAME", required=True, help="Project id")
-def model_list(project_id, **kwargs):
+@click.option(
+    "--format",
+    default="text",
+    show_default=True,
+    type=click.Choice(["text", "json"], case_sensitive=True),
+    metavar="FORMAT",
+    required=False,
+    help="The formatting style for commands output (choose from text, json)",
+)
+def model_list(project_id, format, **kwargs):
     model_list_result = execute_models_list(project_id)
     columns = ["Model id", "Display name", "Creation date", "Last updated"]
-    if kwargs["format"] == "json":
+    if format == "json":
         output_as_json(model_list_result)
-    elif kwargs["format"] == "text":
+    elif format == "text":
         output_as_table(model_list_result.project.models, parse_model, headers=columns)
