@@ -14,6 +14,8 @@ from .describe.ui import model_describe
 from .executions.execution_commands_group import execution_commands_group
 from .init.ui import model_init
 from .list.ui import model_list
+from .list_models.ui import list_models
+from .metadata.ui import list_models_metadata
 from .runtime.runtime_commands_group import runtime_commands_group
 
 
@@ -38,3 +40,5 @@ models_command_group.add_command(deploy_group, "deploy")
 models_command_group.add_command(models_undeploy, "undeploy")
 models_command_group.add_command(model_describe)
 models_command_group.add_command(runtime_commands_group)
+models_command_group.add_command(list_models)
+models_command_group.add_command(list_models_metadata)
