@@ -7,9 +7,18 @@ from qwak_sdk.inner.tools.cli_tools import QwakCommand
 
 @click.command("delete", cls=QwakCommand)
 @click.option("--project-id", metavar="NAME", required=True, help="Project name")
-def delete_project(project_id, **kwargs):
+@click.option(
+    "--format",
+    default="text",
+    show_default=True,
+    type=click.Choice(["text", "json"], case_sensitive=True),
+    metavar="FORMAT",
+    required=False,
+    help="The formatting style for commands output (choose from text, json)",
+)
+def delete_project(project_id, format, **kwargs):
     response = execute_delete(project_id)
-    if kwargs["format"] == "json":
+    if format == "json":
         print(MessageToJson(response))
     else:
         print(f"Project deleted\nproject id : {project_id}")
